@@ -12,6 +12,9 @@ from .entity import (
     FileTemplateVariables,
     FilesTemplateVariables,
     RandomTemplateVariables,
+    TaskDeleteRequest,
+    TaskDetail,
+    TaskItem,
     TaskRequest
 )
 from .dto import (
@@ -26,9 +29,14 @@ from .dto import (
     FileTemplateVariablesDTO,
     FilesTemplateVariablesDTO,
     RandomTemplateVariablesDTO,
+    TaskDeleteRequestDTO,
+    TaskDetailDTO,
+    TaskItemDTO,
     TaskRequestDTO
 )
 from .value_obj import (
+    Status,
+    UDate,
     UDict,
     UInt,
     UStr
@@ -107,8 +115,8 @@ class ClusterConfigDataAssembler(Assembler):
         )
     def to_dto(self, x:ClusterConfigData):
         return ClusterConfigDataDTO(
-            data_server = datapipe_server_info_assembler.to_do(x.data_server),
-            data = [datapipe_data_info_assembler.to_do(m) for m in x.data]
+            data_server = datapipe_server_info_assembler.to_dto(x.data_server),
+            data = [datapipe_data_info_assembler.to_dto(m) for m in x.data]
         )
 cluster_config_data_assembler=ClusterConfigDataAssembler()
 
@@ -127,7 +135,7 @@ class ClusterConfigAssembler(Assembler):
         return ClusterConfigDTO(
             cluster_name = x.cluster_name.get_value(),
             region_id = x.region_id.get_value(),
-            config_data = None if x.config_data is None else cluster_config_data_assembler.to_do(x.config_data),
+            config_data = None if x.config_data is None else cluster_config_data_assembler.to_dto(x.config_data),
             entry_point = None if x.entry_point is None else [m.get_value() for m in x.entry_point],
             timeout = x.timeout.get_value()
         )
@@ -145,7 +153,7 @@ class BootstrapInfoAssembler(Assembler):
         )
     def to_dto(self, x:BootstrapInfo):
         return BootstrapInfoDTO(
-            cluster_config = cluster_config_assembler.to_do(x.cluster_config),
+            cluster_config = cluster_config_assembler.to_dto(x.cluster_config),
             template = x.template.get_value(),
             platform = x.platform.get_value(),
             patch_setting = None if x.patch_setting is None else x.patch_setting.get_value()
@@ -274,7 +282,7 @@ class TaskRequestAssembler(Assembler):
         return TaskRequestDTO(
             task_name = x.task_name.get_value(),
             region_id = x.region_id.get_value(),
-            condition = condition_assembler.to_do(x.condition),
+            condition = condition_assembler.to_dto(x.condition),
             git_url = None if x.git_url is None else x.git_url.get_value(),
             git_branch = None if x.git_branch is None else x.git_branch.get_value(),
             task_type = None if x.task_type is None else x.task_type.get_value(),
@@ -295,3 +303,70 @@ class TaskRequestAssembler(Assembler):
             cluster_name = None if x.cluster_name is None else x.cluster_name.get_value()
         )
 task_request_assembler=TaskRequestAssembler()
+
+
+
+class TaskDeleteRequestAssembler(Assembler):
+    def to_entity(self, dto: TaskDeleteRequestDTO):
+        return TaskDeleteRequest(
+            task_name = None if dto.task_name is None else UStr(dto.task_name),
+            task_id = None if dto.task_id is None else UStr(dto.task_id),
+            delay = None if dto.delay is None else UInt(dto.delay)
+        )
+    def to_dto(self, x:TaskDeleteRequest):
+        return TaskDeleteRequestDTO(
+            task_name = None if x.task_name is None else x.task_name.get_value(),
+            task_id = None if x.task_id is None else x.task_id.get_value(),
+            delay = None if x.delay is None else x.delay.get_value()
+        )
+task_delete_request_assembler=TaskDeleteRequestAssembler()
+
+
+
+class TaskDetailAssembler(Assembler):
+    def to_entity(self, dto: TaskDetailDTO):
+        return TaskDetail(
+            detail_id = UStr(dto.detail_id),
+            ip = UStr(dto.ip),
+            node_status = None if dto.node_status is None else Status(dto.node_status),
+            job_status = None if dto.job_status is None else Status(dto.job_status),
+            exception = None if dto.exception is None else UStr(dto.exception)
+        )
+    def to_dto(self, x:TaskDetail):
+        return TaskDetailDTO(
+            detail_id = x.detail_id.get_value(),
+            ip = x.ip.get_value(),
+            node_status = None if x.node_status is None else x.node_status.get_value(),
+            job_status = None if x.job_status is None else x.job_status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value()
+        )
+task_detail_assembler=TaskDetailAssembler()
+
+
+
+class TaskItemAssembler(Assembler):
+    def to_entity(self, dto: TaskItemDTO):
+        return TaskItem(
+            request = None if dto.request is None else task_request_assembler.to_entity(dto.request),
+            delete_request = None if dto.delete_request is None else task_delete_request_assembler.to_entity(dto.delete_request),
+            task_id = UStr(dto.task_id),
+            creation_time = UDate(dto.creation_time),
+            status = Status(dto.status),
+            details = None if dto.details is None else [task_detail_assembler.to_entity(m) for m in dto.details],
+            entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
+            exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
+            exception = UStr(dto.exception)
+        )
+    def to_dto(self, x:TaskItem):
+        return TaskItemDTO(
+            request = None if x.request is None else task_request_assembler.to_dto(x.request),
+            delete_request = None if x.delete_request is None else task_delete_request_assembler.to_dto(x.delete_request),
+            task_id = x.task_id.get_value(),
+            creation_time = x.creation_time.get_value(),
+            status = x.status.get_value(),
+            details = None if x.details is None else [task_detail_assembler.to_dto(m) for m in x.details],
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            exception = x.exception.get_value()
+        )
+task_item_assembler=TaskItemAssembler()
