@@ -12,6 +12,9 @@ from .entity import (
     FileTemplateVariables,
     FilesTemplateVariables,
     RandomTemplateVariables,
+    TaskDeleteRequest,
+    TaskDetail,
+    TaskItem,
     TaskRequest
 )
 from .do import (
@@ -26,9 +29,14 @@ from .do import (
     FileTemplateVariablesDO,
     FilesTemplateVariablesDO,
     RandomTemplateVariablesDO,
+    TaskDeleteRequestDO,
+    TaskDetailDO,
+    TaskItemDO,
     TaskRequestDO
 )
 from .value_obj import (
+    Status,
+    UDate,
     UDict,
     UInt,
     UStr
@@ -295,3 +303,70 @@ class TaskRequestConverter(Converter):
             cluster_name = None if x.cluster_name is None else x.cluster_name.get_value()
         )
 task_request_converter=TaskRequestConverter()
+
+
+
+class TaskDeleteRequestConverter(Converter):
+    def to_entity(self, do: TaskDeleteRequestDO):
+        return TaskDeleteRequest(
+            task_name = None if do.task_name is None else UStr(do.task_name),
+            task_id = None if do.task_id is None else UStr(do.task_id),
+            delay = None if do.delay is None else UInt(do.delay)
+        )
+    def to_do(self, x:TaskDeleteRequest):
+        return TaskDeleteRequestDO(
+            task_name = None if x.task_name is None else x.task_name.get_value(),
+            task_id = None if x.task_id is None else x.task_id.get_value(),
+            delay = None if x.delay is None else x.delay.get_value()
+        )
+task_delete_request_converter=TaskDeleteRequestConverter()
+
+
+
+class TaskDetailConverter(Converter):
+    def to_entity(self, do: TaskDetailDO):
+        return TaskDetail(
+            detail_id = UStr(do.detail_id),
+            ip = UStr(do.ip),
+            node_status = None if do.node_status is None else Status(do.node_status),
+            job_status = None if do.job_status is None else Status(do.job_status),
+            exception = None if do.exception is None else UStr(do.exception)
+        )
+    def to_do(self, x:TaskDetail):
+        return TaskDetailDO(
+            detail_id = x.detail_id.get_value(),
+            ip = x.ip.get_value(),
+            node_status = None if x.node_status is None else x.node_status.get_value(),
+            job_status = None if x.job_status is None else x.job_status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value()
+        )
+task_detail_converter=TaskDetailConverter()
+
+
+
+class TaskItemConverter(Converter):
+    def to_entity(self, do: TaskItemDO):
+        return TaskItem(
+            request = None if do.request is None else task_request_converter.to_entity(do.request),
+            delete_request = None if do.delete_request is None else task_delete_request_converter.to_entity(do.delete_request),
+            task_id = UStr(do.task_id),
+            creation_time = UDate(do.creation_time),
+            status = Status(do.status),
+            details = None if do.details is None else [task_detail_converter.to_entity(m) for m in do.details],
+            entry_time = None if do.entry_time is None else UDate(do.entry_time),
+            exit_time = None if do.exit_time is None else UDate(do.exit_time),
+            exception = UStr(do.exception)
+        )
+    def to_do(self, x:TaskItem):
+        return TaskItemDO(
+            request = None if x.request is None else task_request_converter.to_do(x.request),
+            delete_request = None if x.delete_request is None else task_delete_request_converter.to_do(x.delete_request),
+            task_id = x.task_id.get_value(),
+            creation_time = x.creation_time.get_value(),
+            status = x.status.get_value(),
+            details = None if x.details is None else [task_detail_converter.to_do(m) for m in x.details],
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            exception = x.exception.get_value()
+        )
+task_item_converter=TaskItemConverter()
