@@ -1,4 +1,5 @@
 from typing import List, Optional, Dict, Tuple, Union
+import datetime
 from pydantic import BaseModel
 
 
@@ -112,4 +113,33 @@ class TaskRequestDO(BaseModel):
     end_style: str = 'delete'
     restart_policy: str = 'never'
     timeout: int = 500
-    cluster_name: Optional[str] = None
\ No newline at end of file
+    cluster_name: Optional[str] = None
+
+
+
+class TaskDeleteRequestDO(BaseModel):
+    task_name: Optional[str]
+    task_id: Optional[str]
+    delay: Optional[int]
+
+
+
+class TaskDetailDO(BaseModel):
+    detail_id: str
+    ip: str
+    node_status: Optional[str]
+    job_status: Optional[str]
+    exception: Optional[str]
+
+
+
+class TaskItemDO(BaseModel):
+    request: Optional[TaskRequestDO]
+    delete_request: Optional[TaskDeleteRequestDO]
+    task_id: str
+    creation_time: datetime.datetime
+    status: str
+    details: Optional[List[TaskDetailDO]]
+    entry_time: Optional[datetime.datetime]
+    exit_time: Optional[datetime.datetime]
+    exception: str
\ No newline at end of file
