@@ -2,6 +2,8 @@ import datetime
 from typing import List, Optional, Dict, Tuple, Union
 from ..domain.entity import Entity
 from .value_obj import (
+    Status,
+    UDate,
     UDict,
     UInt,
     UStr
@@ -291,4 +293,77 @@ class TaskRequest(Entity):
         self.end_style = end_style
         self.restart_policy = restart_policy
         self.timeout = timeout
-        self.cluster_name = cluster_name
\ No newline at end of file
+        self.cluster_name = cluster_name
+
+
+
+class TaskDeleteRequest(Entity):
+    def __init__(
+        self,
+        task_name: Optional[UStr],
+        task_id: Optional[UStr],
+        delay: Optional[UInt],
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.task_name = task_name
+        self.task_id = task_id
+        self.delay = delay
+
+
+
+class TaskDetail(Entity):
+    def __init__(
+        self,
+        detail_id: UStr,
+        ip: UStr,
+        node_status: Optional[Status],
+        job_status: Optional[Status],
+        exception: Optional[UStr],
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.detail_id = detail_id
+        self.ip = ip
+        self.node_status = node_status
+        self.job_status = job_status
+        self.exception = exception
+
+
+
+class TaskItem(Entity):
+    def __init__(
+        self,
+        request: Optional[TaskRequest],
+        delete_request: Optional[TaskDeleteRequest],
+        task_id: UStr,
+        creation_time: UDate,
+        status: Status,
+        details: Optional[List[TaskDetail]],
+        entry_time: Optional[UDate],
+        exit_time: Optional[UDate],
+        exception: UStr,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.request = request
+        self.delete_request = delete_request
+        self.task_id = task_id
+        self.creation_time = creation_time
+        self.status = status
+        self.details = details
+        self.entry_time = entry_time
+        self.exit_time = exit_time
+        self.exception = exception
\ No newline at end of file
